@@ -12,7 +12,7 @@ import peewee
 from playhouse.db_url import connect as url_connect
 from playhouse.migrate import SchemaMigrator
 
-__version__ = '2.0.2'
+__version__ = '2.1.0'
 
 __all__ = ['DatabaseManager', 'MigrationHistory', 'Migrator', 'SchemaMigrator', 'TableCreator']
 
@@ -109,6 +109,8 @@ def build_upgrade_from_model(model):
                 'on_delete': field.on_delete,
                 'on_update': field.on_update,
             }
+            if field.null:
+                kwargs['null'] = True
             coltype = 'int' if field.rel_field.field_type == 'primary_key' else field.rel_field.field_type
             args.append(coltype)
 
@@ -754,11 +756,12 @@ class DatabaseManager:
         LOGGER.info('deleted: {}'.format(migration))
         return True
 
-    def upgrade(self, target=None):
+    def upgrade(self, target=None, fake=False):
         """
         Run all the migrations (up to target if specified). If no target, run all upgrades.
 
         :param target: Migration target to limit upgrades.
+        :param fake: Should the migration actually run?.
         :return: True if upgrade was successful, otherwise False.
         :rtype: bool
         """
@@ -777,7 +780,7 @@ class DatabaseManager:
             return True
 
         for name in self.diff:
-            success = self.run_migration(name, 'upgrade')
+            success = self.run_migration(name, 'upgrade', fake=fake)
             # If it didn't work, don't try any more and exit.
             if not success:
                 return False
@@ -786,11 +789,12 @@ class DatabaseManager:
                 break
         return True
 
-    def downgrade(self, target=None):
+    def downgrade(self, target=None, fake=False):
         """
         Run all the migrations (down to target if specified). If no target, run one downgrade.
 
         :param target: Migration target to limit downgrades.
+        :param fake: Should the migration actually run?.
         :return: True if downgrade was successful, otherwise False.
         :rtype: bool
         """
@@ -811,7 +815,7 @@ class DatabaseManager:
             return False
 
         for name in diff:
-            success = self.run_migration(name, 'downgrade')
+            success = self.run_migration(name, 'downgrade', fake=fake)
             # If it didn't work, don't try any more.
             if not success:
                 return False
@@ -820,7 +824,7 @@ class DatabaseManager:
                 break
         return True
 
-    def run_migration(self, migration, direction='upgrade'):
+    def run_migration(self, migration, direction='upgrade', fake=False):
         """
         Run a single migration. Does not check to see if migration has already been applied.
 
@@ -836,17 +840,18 @@ class DatabaseManager:
             return False
 
         try:
-            LOGGER.info('{}: {}'.format(direction, migration))
+            LOGGER.info('{}: {} FAKE({})'.format(direction, migration, fake))
             with self.database.transaction():
-                scope = {
-                    '__file__': self.get_filename(migration),
-                }
-                with self.open_migration(migration, 'r') as handle:
-                    exec(handle.read(), scope)
+                if not fake:
+                    scope = {
+                        '__file__': self.get_filename(migration),
+                    }
+                    with self.open_migration(migration, 'r') as handle:
+                        exec(handle.read(), scope)
 
-                method = scope.get(direction, None)
-                if method:
-                    method(self.migrator)
+                    method = scope.get(direction, None)
+                    if method:
+                        method(self.migrator)
 
                 if direction == 'upgrade':
                     MigrationHistory.create(name=migration)
@@ -976,19 +981,20 @@ def cli_revision(ctx, name):
 
 @cli_command.command('upgrade')
 @click.argument('target', default='')
+@click.option('--fake', is_flag=True, help="Update migration table but don't run migration.")
 @click.pass_context
-def cli_upgrade(ctx, target):
+def cli_upgrade(ctx, target, fake):
     """Run database upgrades."""
-    if not ctx.obj.data['manager'].upgrade(target):
+    if not ctx.obj.data['manager'].upgrade(target, fake):
         sys.exit(1)
 
-
 @cli_command.command('downgrade')
 @click.argument('target', default='')
+@click.option('--fake', is_flag=True, help="Update migration table but don't run migration.")
 @click.pass_context
-def cli_downgrade(ctx, target):
+def cli_downgrade(ctx, target, fake):
     """Run database downgrades."""
-    if not ctx.obj.data['manager'].downgrade(target):
+    if not ctx.obj.data['manager'].downgrade(target, fake):
         sys.exit(1)
 
 
